@@ -1,10 +1,16 @@
 import logging
-import sqlite3
-from ..db import load_routine, list_routine
+logger = logging.getLogger(__name__)
 from ..utils import range_to_str, yprint, run_routine
 
 
 def show_routine(args):
+    import sqlite3
+    try:
+        from ..db import load_routine, list_routine
+    except Exception as e:
+        logger.error(e)
+        return
+
     # List routines
     if args.routine_name is None:
         try:
@@ -31,4 +37,4 @@ def show_routine(args):
     try:
         run_routine(routine, args.yes, None, args.verbose)
     except Exception as e:
-        logging.error(e)
+        logger.error(e)
